@@ -19,7 +19,7 @@ from seshat.source.saver.base import POSTGRES, SaveConfig
 from seshat.source.saver.utils import PostgresUtils
 from seshat.transformer.schema import Schema
 from seshat.transformer.schema.base import UpdateFuncs
-from seshat.transformer.trimmer.base import NaNTrimmer
+from seshat.transformer.trimmer import NaNTrimmer
 
 
 class SQLDBSaver(SQLMixin, Saver):
@@ -31,6 +31,9 @@ class SQLDBSaver(SQLMixin, Saver):
             self.create_index(config)
 
             selected_sf = sf.get(config.sf_key)
+            if selected_sf.empty:
+                continue
+
             has_id = False
             for col in config.schema.cols:
                 if col.is_id:
